﻿using System;
using Ozeki.Media;
using Ozeki.VoIP;

namespace _07_Parallel_calls
{
    class CallHandler
    {
        ICall _call;
        MediaConnector _mediaConnector;
        MP3StreamPlayback _mp3Player;
        PhoneCallAudioSender _phoneCallAudioSender;

        public CallHandler(ICall call)
        {
            _call = call;

            _phoneCallAudioSender = new PhoneCallAudioSender();
            _mp3Player = new MP3StreamPlayback(@"..\..\test.mp3");
            _mp3Player.Stopped += mp3Player_Stopped;
            _phoneCallAudioSender.AttachToCall(call);
            _mediaConnector = new MediaConnector();
            _mediaConnector.Connect(_mp3Player, _phoneCallAudioSender);
        }

        public event EventHandler Completed;

        public void Start()
        {
            _call.CallStateChanged += call_CallStateChanged;
            _call.Answer();
        }

        void mp3Player_Stopped(object sender, EventArgs e)
        {
            _call.HangUp();
            OnCompleted();
        }

        void OnCompleted()
        {
            _mediaConnector.Dispose();
            _mp3Player.Dispose();

            var handler = Completed;
            if (handler != null)
                handler(this, EventArgs.Empty);
        }

        void call_CallStateChanged(object sender, CallStateChangedArgs e)
        {
            if (e.State == CallState.Answered)
                _mp3Player.Start();
            else if(e.State.IsCallEnded())
                OnCompleted();
        }
    }
}
